<?php get_header(); ?>
		<div id="primary-content" class="narrowcolumn">
<?php include (TEMPLATEPATH . '/theloop.php'); ?>
<?php comments_template(); ?>
		</div>
<?php get_sidebar(); ?>
<?php get_footer(); ?>
