<?php get_header(); ?>

		<div id="primary-content">
			<h2 class="pagetitle"><?php _e('Error 404 - Not Found','rgb'); ?></h2>
			<div class="entry">
				<p><?php _e('Oh no! You\'re looking for something which just isn\'t here! The URL you entered or followed no longer seems to exist, has been removed, or has been replaced.','rgb'); ?></p>
			</div>
		</div>

<?php get_sidebar(); ?>
<?php get_footer(); ?> 