		</div><!-- end: #main -->
		<div id="footer">
		<!-- Please keep these links -->
		<span>Powered by <a href="http://wordpress.org" title="Link to Wordpress.org" target="_blank">Wordpress</a></span><br />
		<span><a href="http://www.famfamfam.com/lab/icons/silk/" title="slik icons" target="_blank">Slik</a> icons from <a href="http://www.famfamfam.com" title="Link to famfamfam" target="_blank">famfamfam</a></span><br />
		<span><a href="http://getfreeware.net/archives/382.html" title="midnight-blue wordpress theme" target="_blank">Midnight-Blue</a> theme from <a href="http://getfreeware.net" title="Link to getfreeware.net" target="_blank">GetFreeware.net</a></span>

		</div><!-- end: #footer -->
	</div><!--end: #page -->
	<?php wp_footer(); ?>
</body>
</html>