* html #primary-content{background-image:none;}
* html .entry-date{margin-left:-8px;}
* html #navwrap{background:#1a1a1a;filter:alpha(opacity=90);}
* html #s,* html #searchsubmit{filter:alpha(opacity=50);background:#333;border:1px solid #1a1a1a;}
* html #sidebar{position:absolute;margin:10px 0 0;padding:1px;}
* html #primary-content .intro,* html #leavecomment,* html h4.section-title {background-image:none;background-color:#f7f7f7;filter:alpha(opacity=50);}
* html #commentlist li {background:none;}