</div> <!-- wrapper -->
<div id="footer"><div><div><div>
	<a href="<?php bloginfo('rss2_url'); ?>">Entries (RSS)</a> and <a href="<?php bloginfo('comments_rss2_url'); ?>">Comments (RSS)</a>.<br />
	Powered by <a href="http://wordpress.org/" title="Powered by WordPress.">WordPress</a>. Theme <a href="http://srinig.com/wordpress/themes/evanescence/">Evanescence</a>.<br />
	<?php wp_footer(); ?>
<!--	<?php echo get_num_queries(); ?> queries. <?php timer_stop(1); ?> seconds. -->
</div></div></div></div>
</div> <!-- page -->
</body>
</html>
