
<div style="clear:both;"></div>
</div>
</div> <!-- eo content -->

	<div id="footer">
	<div id="footer-inner">
		<p><?php bloginfo('name'); ?> is powered by	<a href="http://wordpress.org/">WordPress</a></p>
	
	</div>
	</div>

	
	<div id="credit">
		<!-- Please leave the credit link intact, under the terms of the GPL license -->
		<p><a href="http://www.blogchemistry.com/">WordPress Themes</a></p>
	</div>
	
</div>
</div>
</div>
</div>

<?php wp_footer(); ?>
</body>
</html>