<div id="footer">


<p><a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/3.0/us/"><img alt="Creative Commons License" style="border-width:0" src="http://i.creativecommons.org/l/by-nc-nd/3.0/us/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-nd/3.0/us/">Creative Commons Attribution-Noncommercial-No Derivative Works 3.0 United States License</a>.

		<p><?php bloginfo('name'); ?> is powered by <a href="http://wordpress.org">WordPress</a> and styled by <a href="http://www.acroyear2.org/infimum/">Infimum</a>. <a href="http://validator.w3.org/check/referer" title="Validate the XHTML source for this page">Valid <abbr title="eXtensible HyperText Markup Language">XHTML</abbr></a> and <a href="http://jigsaw.w3.org/css-validator/check/referer" title="Validate the CSS stylesheet for this page">valid <abbr title="Cascading StyleSheets">CSS</abbr></a>. <?php wp_register('',' or '); ?><?php wp_loginout(); ?>. <?php wp_meta(); ?></p>


</div>

</div>

<?php wp_footer(); ?>

</body>
</html>