<div id="footer">

	<p id="legal"><a href="<?php bloginfo('url'); ?>"><?php bloginfo('name'); ?></a> is powered by <a href="http://wordpress.org">WordPress</a>. WordPress Theme by <a href="http://webdemar.com" title="WordPress Theme">webdemar</a>.</p>

</div>

</body>
</html>