/*
	Theme Name: Infimum
	Theme URI: http://www.acroyear2.org/infimum/
	Description: A very minimal theme, widget-ready, gravatar-supporting, and standards-compliant. Black on white with blue highlights, two columns with a thin right sidebar. Possibly the minimalest of minimalist themes.
	Version: 1.3
	Author: Alex Smith
	Author URI: http://www.acroyear2.org/
	Tags: widgets, blue, white, right sidebar, fixed width, two columns, valid CSS, valid XHTML, widget ready, 2 column, 2 columns, clean, simple, free, Gravatar, light, minimal, minimalist, sidebar right, tags, Two Column, widgetized, widget
*/

/* Todo list:
   * Have a better content title for time-based archives.
   * Put the page number of paged archives in the content title.
   * Make colors user-editable.
*/

/* Changelog:
	1.3: Added real blog tagline support (previous was fake): if you have a tagline it displays it prominently, if you have no tagline it looks exactly like it did before. Made list-of-posts pages better. Removed an ugly line that happened sometimes in the comments. Bumped version number because of requirement in WordPress Theme Directory. Released 2008/07/31.
	1.1: Added categories, multipule authors, blog tagline, and gravatar support. Made compatible with WordPress Theme Directory. Changed version numbering scheme. Released 2008/07/29.
	1.02: Compatibility updates. Released 2008/07/21.
	1.01: Fixed comment date bug. Released 2008/07/01.
	1.0: Initial release. Released 2008/03/23.
*/

/* whole page */
body {
	margin: 0em;
	padding: 0em;

	color: black;
	background: white;
	
	font-family: "Lucida Grande", "Lucida Sans", "Lucida", sans-serif;
	font-size: 0.75em;
	
	line-height: 1.5em;
}

#page {
	margin: 8em auto;
	padding: 0em;
	
	width: 60em;
}

a {
	color: #1070c0;
	background: inherit;
	
	text-decoration: none;
}

a:visited {
	color: #0060b0;
	background: inherit;
}

a:hover {
	color: white;
	background: #1070c0;
}

.alignleft {
	float: left;
}

.alignright {
	float: right;
}

blockquote {
	margin: 1em 2em 1em 1em;
	
	font-size: 0.9em;
}
/* end whole page */

/* header */
#header {
	margin: 0em;
	padding: 0em;
	
	width: 60em;
}

#header h1 {
	margin: 0em;
	padding: 0em;
	
	font-size: 4em;
	
	float: left;
}

#header #tagline {
	margin: 0em 0em 0em 2em;
	border: 0px solid gray;
	border-left: 1px solid gray;
	padding: 0.5em 0em 0.5em 2em;
	
	color: gray;
	background: inherit;
	
	float: left;
}
/* end header */

/* content area */
#content {
	margin: 4em 0em;
	padding: 0em;
	width: 40em;
	
	float: left;
}

#content h2 {
	margin: 0em 0em 1em;
	padding: 0em;
	
	font-size: 1.5em;
}

#content .post {
	margin: 2em 0em 0em;
}

#content h3 {
	margin: 0em;
	padding: 0em;
	
	font-size: 1.25em;
}

#content .postmetadata {
	color: #777777;
	background: inherit;
	
	font-size: 0.9em;
}

#content .navigation {
	margin: 2em 0em 0em;
	padding: 0em;
	
	display: block;
}

#content .goback {
	margin: 0em 0.5em 0em 0em;
	padding: 0em;
	
	float: left;
	
	font-size: 1.25em;
}

#content .goforward {
	margin: 0em 0em 0em 0.5em;
	padding: 0em;
	
	float: right;
	
	font-size: 1.25em;
}

#content #comments {
	margin: 2em 0em 1em;
	padding: 0em;
	
	clear: both;
}

#content .commentlist {	
	margin: 0em;
	padding: 0em;
	
	font-size: 0.9em;
}

#content .commentlist li {
	margin: 0em;
	padding: 0em;
	
	list-style-type: none;
}

#content .commentlist img.avatar {
	float: right;
	margin-left: 1em;
}

#content .commentmetadata {
	margin: 0em 0em 2em;
	color: #777777;
	background: inherit;
}

#content #respond {
	margin: 2em 0em 1em;
	padding: 0em;
	
	clear: both;
}
/* end content area */

/* these rules are added for compatibility with WordPress Theme Directory */

.aligncenter {
	display: block;
	margin-left: auto;
	margin-right: auto;
}

.alignleft {
	float: left;
}

.alignright {
	float: right;
}

.wp-caption {
	border: 1px solid #ddd;
	text-align: center;
	background-color: #f3f3f3;
	padding-top: 4px;
	margin: 10px;
}

.wp-caption img {
	margin: 0;
	padding: 0;
	border: 0 none;
}

.wp-caption-dd {
	font-size: 11px;
	line-height: 17px;
	padding: 0 4px 5px;
	margin: 0;
}

/* end Theme Directory compatibility */

/* sidebar */
#sidebar {
	margin: 4em 0em;
	padding: 0em;

	width: 16em;
	float: right;
}

#sidebar h2 {
	margin: 0em;
	padding: 0em;

	font-size: 1.0em;
}

#sidebar h2 a, #sidebar h2 a:visited {
	color: black;
	background: inherit;
}

#sidebar h2 a:hover {
	color: white;
	background: #1070c0;
}

#sidebar ul {
	margin: 0em;
	padding: 0em;
}

#sidebar ul li {
	margin: 0em 0em 1em;
	padding: 0em;
	
	list-style-type: none;
}

#sidebar ul li p, #sidebar ul li ul, #sidebar ul li ol {
	font-size: 0.8em;
}

#sidebar ul li ul li, #sidebar ul li ol li {
	margin: 0em;
	padding: 0em;
}

#sidebar .textwidget {
	font-size: 0.8em;
}
/* end sidebar */

/* footer */
#footer {
	margin: 0em;
	padding: 0em;
	
	width: 60em;
	clear: both;
}

#footer p {
	margin: 0em;
	padding: 0em;
	
	font-size: 0.8em;
	
	text-align: center;
}
/* end footer */
