	<div id="sidebar">
	<div>
		<ul>
			<?php if ( !function_exists('dynamic_sidebar')
    	    || !dynamic_sidebar() ) : ?>
			
			<!-- Author information is disabled per default. Uncomment and fill in your details if you want to use it.
			<li><h2>Author</h2>
			<p>A little something about you, the author. Nothing lengthy, just an overview.</p>
			</li>
			-->
			
			<li><h2>Pages</h2>
				<ul>
					<?php wp_list_pages('title_li='); ?>
				</ul>
			</li>
			<li><h2>Recent Posts</h2>
				<ul>
				<?php get_archives('postbypost', '10', 'custom', '<li>', '</li>'); ?>
				</ul>
			</li>
			<li><h2>Categories</h2>
				<ul>
					<?php wp_list_cats('sort_column=name&optioncount=0&hierarchical=1'); ?>
				</ul>
			</li>

			<li><h2>Archives</h2>
				<ul>
					<?php wp_get_archives('type=monthly'); ?>
				</ul>
			</li>

			<?php /* If this is the frontpage */ if ( is_home() || is_page() ) { ?>				
				<?php get_links_list(); ?>
				
			<li><h2>Meta</h2>
			<ul>
				<?php wp_register(); ?>
				<li><?php wp_loginout(); ?></li>
				<li><a href="http://validator.w3.org/check/referer" title="This page validates as XHTML 1.0 Transitional">Valid <abbr title="eXtensible HyperText Markup Language">XHTML</abbr></a></li>
				<li><a href="http://gmpg.org/xfn/"><abbr title="XHTML Friends Network">XFN</abbr></a></li>
				<li><a href="http://wordpress.org/" title="Powered by WordPress, state-of-the-art semantic personal publishing platform.">WordPress</a></li>
				<?php wp_meta(); ?>
			</ul>
			</li>
			<?php } ?>
		<?php endif; ?>
			
		</ul> 
	</div>
	</div>
