<form method="get" id="searchform" action="<?php bloginfo('home'); ?>/">
<input type="text" size="12" name="s" id="s" value="search..."  onblur="if(this.value=='') this.value='search...';" onfocus="if(this.value=='search...') this.value='';"/>
</form>
