<br class="clear" />
<hr />
<div id="footer">
  <p> <?php printf(__('%1$s is powered by %2$s and %3$s'), get_bloginfo('name'), '<a href="http://wordpress.org/" title="WordPress.org">WordPress '.get_bloginfo('version').'</a>', '<a href="http://xuyiyang.com/wordpress-themes/rgb/">RGB Beta</a>')?> </p>
  <!-- <?php echo get_num_queries(); ?> queries. <?php timer_stop(1); ?> seconds. -->
</div>
<?php wp_footer(); ?>
</div>
</div>
</body></html>