<?php get_header(); ?>


<div id="content">
<div id="content-inner">

<div id="main">

	<div class="post">
	<div class="entry">
		<h2>Not Found</h2>
		<p>Sorry, you are looking for something that isn't here.</p>
	</div>
	</div>	
	
	</div> <!-- eof main -->

<?php get_sidebar(); ?>

<?php get_footer(); ?>


