/*  
Theme Name: RGB
Theme URI: http://xuyiyang.com/wordpress-themes/rgb/
Description: A crsip, simple and highly customizable theme for WordPress.
Version: 2.0.2
Author: Xu Yiyang
Author URI: http://xuyiyang.com/
Tags: gray, custom header, fixed width, two columns, widgets, option page, easy-customization.

This theme uses the wonderful Sweetie Icons by Joseph North:
http://sweetie.sublink.ca/
*/

*,html {
margin:0;
padding:0;
}

body {
font:62.5% "Lucida Grande", Segoe UI, Verdana, Arial, sans-serif;
text-align:center;
}

fieldset,select {
border:none;
}

acronym,abbr,span.caps {
cursor:help;
}

acronym,abbr {
border-bottom:1px dashed #ddd;
}

blockquote {
border-left:3px solid #ddd;
padding-left:10px;
margin:20px;
}

code,pre,kbd {
font:1em 'Courier New', Courier, sans-serif;
}

small {
font:1em Arial, Helvetica, sans-serif;
color:#aaa;
}

strike,del {
color:#aaa;
text-decoration:line-through;
}

label {
cursor:pointer;
}

h1,h2,h3,h4 {
font-family:"Trebuchet MS", "Tahoma", sans-serif;
text-transform:uppercase;
}

h1 {
text-align:left;
font-size:2em;
padding:45px 0 5px 25px;
}

h2 {
font-size:1.7em;
margin:5px 0;
}

h3,h4 {
font-size:1.3em;
margin:15px 0 0;
}

p {
margin:0 0 10px;
}

#container {
position:relative;
font-size:1.2em;
width:100%;
margin:0 auto;
}

#content {
width:940px;
margin:0 auto;
}

#header {
line-height:1.2em;
width:940px;
height:160px;
background:url(images/bg_nav_ul.png) repeat transparent;
margin:10px auto 0;
}

#header .description {
text-align:left;
font-size:1em;
padding:5px 0 5px 27px;
}

#navwrap {
width:100%;
background:url(images/bg_nav_ul.png) repeat transparent;
margin:-30px 0 0;
}

#nav {
font-family:"Trebuchet MS", "Tahoma", sans-serif;
display:block;
text-align:left;
letter-spacing:0.15em;
text-transform:uppercase;
list-style:none;
height:30px;
width:940px;
margin:0 auto !important;
}

#nav li {
float:left;
line-height:22px;
margin:0 3px;
padding:3px 0;
}

#nav li a {
display:block;
text-decoration:none;
font-size:.9em;
font-weight:700;
color:#ccc;
padding:0 8px;
}

#nav li a:hover {
color:#fff;
}

#nav li.current_page_item a {
color:#fff;
background:#555;
}

#nav .rss a,#nav .rss a:hover {
color:#C03;
}

#search {
clear:right;
float:right !important;
width:324px;
line-height:1em;
background:transparent;
margin:0 2px 0 15px !important;
}

#search:hover {
background:transparent;
}

#s {
float:left;
display:block;
font:.9em "Lucida Grande", Segoe UI, Verdana, Arial, sans-serif;
width:250px;
height:16px;
font-size:.9em;
color:#eee;
border:1px solid #333;
background:url(images/bg_input.png) 0 0 repeat-x transparent;
margin:1px 0 0;
padding:3px 3px 1px;
}

#s:focus,#s:hover {
border:1px solid #333;
background:url(images/bg_input.png) 0 -25px repeat-x transparent;
}

#searchsubmit {
float:left;
display:block;
color:#fff;
font:.8em "Trebuchet MS", "Tahoma", sans-serif;
width:60px;
height:22px;
text-transform:uppercase;
cursor:pointer;
border:1px solid #333;
background:url(images/bg_input.png) 0 0 repeat-x transparent;
margin:1px 0 0 4px;
}

#searchsubmit:hover {
background:url(images/bg_input.png) 0 -26px repeat-x transparent;
}

#primary-content {
float:left;
text-align:left;
font-size:1.1em;
line-height:1.6em;
width:580px;
display:inline;
background:url(images/bg_content.png) left top repeat-x;
margin:10px 0 0;
padding:5px;
}

#primary-content ul,#primary-content ol {
margin:8px 0;
}

#primary-content .intro {
font-size:.9em;
font-weight:700;
line-height:1.2em;
background:url(images/bg_cmt.png) repeat;
width:98%;
margin:25px 0 0;
padding:5px;
}

.pagetitle {
text-align:center;
margin:15px 0 0;
padding:5px;
}

.entry {
text-align:left;
padding:10px 8px;
}

.entry ol li {
list-style:decimal outside;
}

.entry-header {
font-size:1.7em;
font-weight:400;
width:500px;
margin:0;
padding:5px 5px 5px 0;
}

.entry-date {
text-align:left;
margin:0 auto 10px -30px;
padding:1px 4px;
float:left;
}

.entry-cmt {
float:right;
font-size:1em;
font-weight:700;
text-transform:uppercase;
cursor:pointer;
margin:-20px -21px 2px 10px;
padding:5px 8px;
}

.entry-content {
clear:both;
}

.entry-footer {
color:#aaa;
text-align:left;
line-height:1.2em;
margin:4px 0 20px;

padding:4px 0;
}

.entry-footer a {
color:#aaa;
}

.entry-footer,.entry-date,.comment-footer {
font-size:.7em;
}

.metacmt {
background:url(images/bg_icons.png) 0 -51px no-repeat;
padding:2px 0 2px 20px;
}

.metacat {
background:url(images/bg_icons.png) 0 -68px no-repeat;
padding:2px 0 2px 16px;
}

.metatag {
color:#aaa;
background:url(images/bg_icons.png) 0 -17px no-repeat;
padding:0 0 0 16px;
}

.metaedit {
background:url(images/bg_icons.png) 0 0 no-repeat;
padding:2px 0 2px 17px;
}

#sidebar {
position:fixed !important;
top:180px !important;
left:55%;
margin-left:82px;
line-height:1.2em;
width:318px;
text-align:left;
font-size:1em;
padding:4px;
}

#sidebar h2 {
text-align:left;
font-size:1.2em;
}

#sidebar ul {
margin:4px;
}

#sidebar ul li {
margin:2px;
padding:2px;
}

#sidebar .tabs li a,#sidebar .tabs li a:link,#sidebar .tabs li a:visited,#sidebar .tabs li a:hover {
font-weight:700;
text-decoration:none;
line-height:1.5em;
}

#sidebar .tabs li.current_page_item a {
text-decoration:none;
background:none;
}

#sidebar .intro {
font-size:.9em;
width:288px;
margin:0 8px 14px;
padding:5px 2px 5px 8px;
}

#sidebar .st-tag-cloud {
line-height:1.4em;
margin:2px 0 2px 12px;
padding:5px;
}

.entry ul li,#commentlist .comment-content ul li {
list-style-image:url(images/bg_li.png);
}

* html .ui-tabs-nav,*:first-child+html .ui-tabs-nav {
display:inline-block;
}

#togglewidgets {
float:left !important;
width:290px;
text-align:center;
margin:5px;
}

.ui-tabs-nav {
width:100%;
}

.ui-tabs-nav li {
display:inline;
}

.ui-tabs-nav:after {
display:block;
clear:both;
content:" ";
}

.ui-tabs-nav a {
text-align:center;
font-size:.8em;
background:#555;
color:#27537a;
font-weight:700;
line-height:16px;
text-decoration:none;
white-space:nowrap;
outline:0;
width:40px;
margin:-1px 0 0;
padding:4px;
}

.ui-tabs-nav a:hover,.ui-tabs-nav .ui-tabs-unselect a:hover,.ui-tabs-selected a,.ui-tabs-selected a:hover {
color:#fff !important;
background:#1a1a1a;
cursor:pointer;
}

.ui-tabs-panel {
background:transparent;
width:314px;
margin:0 12px 14px 2px;
padding:0 2px;
}

#footer {
clear:both;
float:left;
height:30px;
width:574px;
margin:-15px 0 0;
}

#footer p {
color:#fff;
text-align:center;
font-size:.9em;
line-height:1.3em;
padding:8px;
}

#footer p a {
color:#ddd;
}

#comment-section {
text-align:left;
margin:30px 10px;
}

h4.section-title {
width:98%;
font-size:1.5em;
font-weight:400;
text-align:center;
background:url(images/bg_cmt.png) repeat;
margin:5px auto;
padding:5px;
}

#leavecomment {
width:97%;
text-align:center;
color:#aaa;
font-size:1.8em;
margin:30px auto !important;
}

#commentform {
margin:15px 0;
}

input#author,input#email,input#url,textarea#comment {
color:#1a1a1a;
background:#f7f7f7;
border-top:1px solid #777;
border-right:1px solid #bbb;
border-bottom:1px solid #ccc;
border-left:1px solid #ddd;
font:.9em "Lucida Grande", Segoe UI, Verdana, Arial, sans-serif;
padding:2px;
}

#commentform input:focus,#commentform textarea:focus,#commentform input:hover,#commentform textarea:hover {
background:#fff;
}

textarea#comment {
width:98%;
padding:2px;
}

#commentform #submit,.thickboxbtn a {
clear:both;
float:right;
background:#C03;
color:#fff !important;
border:2px solid #900;
font:Georgia, "Times New Roman", Times, serif;
font-weight:700;
font-size:.8em !important;
margin:5px 4px 4px;
padding:3px 8px;
}

#commentform #submit:hover,.thickboxbtn a:hover {
background:#900;
}

#commentlist li {
list-style:none;
line-height:1.6em;
background:url(images/bg_cmt.png) repeat;
margin:10px 0;
padding:8px;
}

#commentlist li img {
border:0;
padding:0;
}

#commentlist li span.gravatar {
float:right;
border:2px solid #ddd;
width:32px;
height:32px;
}

.comment-header {
text-align:left;
font-size:1.5em;
margin:2px;
}

.comment-content {
margin:10px;
}

.comment-footer {
text-align:left;
margin:0;
}

.aligncenter,div.aligncenter {
display:block;
margin-left:auto;
margin-right:auto;
}

.alignleft {
float:left;
}

.alignright {
float:right;
}

.wp-caption {
border:1px solid #ddd;
text-align:center;
background-color:#f3f3f3;
padding-top:4px;
-moz-border-radius:3px;
-khtml-border-radius:3px;
-webkit-border-radius:3px;
border-radius:3px;
margin:10px;
}

.wp-caption img {
border:0 none;
margin:0;
padding:0;
}

.wp-caption p.wp-caption-text {
font-size:11px;
line-height:17px;
margin:0;
padding:0 4px 5px;
}

.navigation {
display:block;
font-size:.9em;
text-align:center;
margin:8px 4px;
}

.alert {
font-size:.8em;
color:#EB4835;
background:#FFC;
border:1px solid #C03;
text-align:center;
margin:10px auto;
padding:3px;
}

a,a:link,a:active,a:visited,a:hover,cite,ins,.entry p a,.entry li a,.entry p a:hover,.entry li a:hover {
text-decoration:none;
}

hr,hr,.tabs h2,.counter,.ui-tabs-hide {
display:none;
}

ul li,ol li,ul li,ol li,#sidebar ul,#TB_ajaxContent {
list-style:none;
}

.entry li,.entry li,#commentlist .comment-content li {
margin:0 5px 0 30px;
}

.clear {
clear:both;
}